@@ -7,6 +7,10 @@
 #include <windows.h>
 #endif
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 class MainApp : public QtSingleApplication
 {
     Q_OBJECT
